==> haskell-stm-chans-3.0.0.4-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-Cr78aZkwhsaHBOCaXlDPX0
key: stm-chans-3.0.0.4-Cr78aZkwhsaHBOCaXlDPX0
license: BSD3
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
author: wren gayle romano, Thomas DuBuisson
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
abi: 2bf542200bcbc1d5c98984c01a71e7c4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-Cr78aZkwhsaHBOCaXlDPX0
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-chans-3.0.0.4-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
key: stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
license: BSD-3-Clause
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
author: wren gayle romano, Thomas DuBuisson
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
abi: 5db7f4d4b6f27dc43b83e36d4a6a34be
exposed: True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
import-dirs: /usr/lib/ghc-8.4.3/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
depends:
    base-4.11.1.0 stm-2.4.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
